Skip to contents

Build a generic system metadata table from a list of padloc models.

Usage

build_generic_hmm_meta(hmm_protein_key)

Arguments

hmm_protein_key

A base::data.frame() with two columns, hmm.name containing the names of each physical hmm file, and protein.name containing the corresponding protein name that each hmm is associated with.

Value

A tibble::tibble().