Skip to contents

Build a list of generic padloc models from a list of loci.

Usage

build_generic_padloc_models(df, loci_col, delim = "__", name_prefix = "SYS_")

Arguments

df

A base::data.frame() with at least one column, containing the locus structures in the form geneA__geneB__geneC, where __ indicates separation between genes and can optionally be set to any other delimiter by specifying delim.

loci_col

The name of the column containing locus structures,

delim

The delimiter that separates gene names.

name_prefix

A prefix to use when generating generic names for each model.

Value

A tibble::tibble().