Build a generic system metadata table from a list of padloc models
Source:R/io-metadata-tables.R
build_generic_sys_meta.RdBuild a generic system metadata table from a list of padloc models.
Arguments
- model_list
A
base::list()of padloc models.