Compare system model files against the hmm metadata table.
Source:R/comparison-methods.R
compare_sys_files_hmm_meta.RdCompare system model files against those listed in hmm_meta.txt.
Arguments
- models_expanded
A
base::list()of padloc-db system models (i.e. as read in bymulti_read_padloc_model()).- hmm_meta_expanded
A padloc-db HMM metadata file (i.e. as read in by
read_hmm_meta()).
Value
A base::list() of three tibble::tibble()s.