Compare system model files against those listed in sys_meta.txt
Source:R/comparison-methods.R
compare_sys_meta_sys_groups.RdCompare system model files against those listed in hmm_meta.txt.
Arguments
- sys_meta
A padloc-db system metadata file (i.e. as read in by
read_sys_meta()).- sys_groups
A padloc-db system groups metadata file (i.e. as read in by
read_sys_groups()).
Value
a base::list() of three tibble::tibble()s.