Skip to contents

Expand secondary gene assignments in all categories of genes in a list of padloc models into their underlying genes.

Usage

expand_gene_groups_all(models, hmm_meta)

Arguments

models

A list of padloc models.

hmm_meta

A padloc-db HMM metadata table.

Value

A base::list() of padloc models with expanded genes.

Examples

model <- multi_read_padloc_model(padlocdev_example("padloc-db/sys"))
hmm_meta <- read_hmm_meta(padlocdev_example("padloc-db/hmm_meta.txt"))