Pull the genes from a list of system models.
Arguments
- sys_list
A
base::list()of system models (i.e. as read in bymulti_read_padloc_model().
Value
a base::character() vector.
Pull the genes from a list of system models.
A base::list() of system models (i.e. as read in by
multi_read_padloc_model().
a base::character() vector.