Skip to contents

Generate a validity report for a list of padloc models.

Usage

report_padloc_model_validity(models)

Arguments

models

A base::list() of system models (i.e. as read in by multi_read_padloc_model().

Value

A purrr::safely() style base::list() with components result

and error. If the model is valid, result is TRUE and error is NULL. If the model is invalid, result is FALSE and error is an error object that describes the reason the model is invalid.