Skip to contents

Copy system description files from one directory to another.

Usage

system_cp_sys(sys_list, path, new_path)

Arguments

sys_list

A character vector listing system description file names to be copied, such as that generated by...

path

The path to

new_path

asd...

Value

Nothing.