Build a generic system metadata table from a list of padloc models
Source:R/io-metadata-tables.R
build_generic_hmm_meta.RdBuild a generic system metadata table from a list of padloc models.
Arguments
- hmm_protein_key
A
base::data.frame()with two columns,hmm.namecontaining the names of each physical hmm file, andprotein.namecontaining the corresponding protein name that each hmm is associated with.