Build a list of generic padloc models from a list of loci
Source:R/io-padloc-model.R
build_generic_padloc_models.RdBuild a list of generic padloc models from a list of loci.
Arguments
- df
A
base::data.frame()with at least one column, containing the locus structures in the formgeneA__geneB__geneC, where__indicates separation between genes and can optionally be set to any other delimiter by specifyingdelim.- loci_col
The name of the column containing locus structures,
- delim
The delimiter that separates gene names.
- name_prefix
A prefix to use when generating generic names for each model.