Convert a dataframe of short dois to long dois
Usage
doi_to_long_df(df, col = doi_short)
Arguments
- df
A data frame containing a column with short dois
- col
The name of the column containing short dois
Value
A data frame with a new column containing long dois