Expand all gene groups in a list of padloc models
Source:R/expand-gene-groups.R
expand_gene_groups_all.RdExpand secondary gene assignments in all categories of genes in a list of padloc models into their underlying genes.
Value
A base::list() of padloc models with expanded genes.
Examples
model <- multi_read_padloc_model(padlocdev_example("padloc-db/sys"))
hmm_meta <- read_hmm_meta(padlocdev_example("padloc-db/hmm_meta.txt"))