A list of all the parameters that make up a padloc model.
Usage
padloc_model(
force_strand,
maximum_separation,
minimum_core,
minimum_total,
core_genes,
secondary_genes,
neutral_genes,
prohibited_genes
)Arguments
- force_strand
A
base::logical(), specifying whether all genes should be on the same strand.- maximum_separation
A
base::integer(), representing the maximum number of unrelated genes that can seperate the genes of a system.- minimum_core
A
base::integer(), representing the minimum number of core genes that must be identified for a complete system.- minimum_total
A
base::integer(), representing the minimum number of total genes that must be identified for a complete system.- core_genes
A
base::character(), listing the names of the core genes that contribute to system completeness.- secondary_genes
A
base::character(), listing the names of the optional genes that contribute to system completeness.- neutral_genes
A
base::character(), listing the names of the neutral genes that do not contribute to system completeness.- prohibited_genes
A
base::character(), listing the names of the prohibited genes that cannot be identified in proximity to the system.
Value
A base::list().